Some spelling fixes

Peter Eisentraut <[email protected]> Fri, 16 Jul 2010 00:32:19 +0300
Newsgroups gmane.comp.python.db.psycopg.devel
Message-ID <[email protected]>
--=-YwfB8yolj8hy1o+wMp0K
Content-Type: text/plain
Content-Transfer-Encoding: 7bit

Here is a patch with a few spelling fixes for the sources.

--=-YwfB8yolj8hy1o+wMp0K
Content-Disposition: attachment; filename="psycopg-spelling-fixes.patch"
Content-Type: text/x-patch; name="psycopg-spelling-fixes.patch"; charset="UTF-8"
Content-Transfer-Encoding: 7bit

diff --git a/doc/src/extensions.rst b/doc/src/extensions.rst
index 268befa..d98320a 100644
--- a/doc/src/extensions.rst
+++ b/doc/src/extensions.rst
@@ -309,7 +309,7 @@ The module exports a few exceptions in addition to the :ref:`standard ones
 
     (subclasses `~psycopg2.OperationalError`)
 
-    Error related to SQL query cancelation.  It can be trapped specifically to
+    Error related to SQL query cancellation.  It can be trapped specifically to
     detect a timeout.
 
     .. versionadded:: 2.0.7
diff --git a/psycopg/cursor_type.c b/psycopg/cursor_type.c
index 1a1e859..d685852 100644
--- a/psycopg/cursor_type.c
+++ b/psycopg/cursor_type.c
@@ -1553,7 +1553,7 @@ static struct PyMemberDef cursorObject_members[] = {
     {"rowcount", T_LONG, OFFSETOF(rowcount), RO,
         "Number of rows read from the backend in the last command."},
     {"arraysize", T_LONG, OFFSETOF(arraysize), 0,
-        "Number of records `fetchmany()` must fetch if not explicitely " \
+        "Number of records `fetchmany()` must fetch if not explicitly " \
         "specified."},
     {"description", T_OBJECT, OFFSETOF(description), RO,
         "Cursor description as defined in DBAPI-2.0."},
diff --git a/psycopg/psycopg.h b/psycopg/psycopg.h
index ea90b5a..d023e47 100644
--- a/psycopg/psycopg.h
+++ b/psycopg/psycopg.h
@@ -153,7 +153,7 @@ HIDDEN char *psycopg_escape_string(PyObject *conn,
 
 #ifdef PSYCOPG_EXTENSIONS
 #define QueryCanceledError_doc \
-"Error related to SQL query cancelation."
+"Error related to SQL query cancellation."
 
 #define TransactionRollbackError_doc \
 "Error causing transaction rollback (deadlocks, serialisation failures, etc)."
diff --git a/setup.py b/setup.py
index bf5281f..2fec5ea 100644
--- a/setup.py
+++ b/setup.py
@@ -114,7 +114,7 @@ class psycopg_build_ext(build_ext):
     def get_compiler(self):
         """Return the name of the C compiler used to compile extensions.
 
-        If a compiler was not explicitely set (on the command line, for
+        If a compiler was not explicitly set (on the command line, for
         example), fall back on the default compiler.
         """
         if self.compiler:
diff --git a/tests/test_transaction.py b/tests/test_transaction.py
index f279bbd..030bf17 100755
--- a/tests/test_transaction.py
+++ b/tests/test_transaction.py
@@ -204,8 +204,8 @@ class DeadlockSerializationTests(unittest.TestCase):
                 error, psycopg2.extensions.TransactionRollbackError))
 
 
-class QueryCancelationTests(unittest.TestCase):
-    """Tests for query cancelation."""
+class QueryCancellationTests(unittest.TestCase):
+    """Tests for query cancellation."""
 
     def setUp(self):
         self.conn = psycopg2.connect(tests.dsn)

--=-YwfB8yolj8hy1o+wMp0K
Content-Type: text/plain; charset="us-ascii"
MIME-Version: 1.0
Content-Transfer-Encoding: 7bit
Content-Disposition: inline

_______________________________________________
Psycopg mailing list
Psycopg-IAPFreCvJWPBWskQ1e/[email protected]
http://lists.initd.org/mailman/listinfo/psycopg

--=-YwfB8yolj8hy1o+wMp0K--